package de.w665.sharepulse.rest.mappings;

import de.w665.sharepulse.rest.ApiRestController;
import de.w665.sharepulse.service.FileService;
import jakarta.servlet.http.HttpServletRequest;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

@Slf4j
@RestController
public class Upload extends ApiRestController {

    private final FileService fileService;

    @Autowired
    public Upload(FileService fileService) {
        this.fileService = fileService;
    }

    // Currently testing
    @PostMapping("/upload")
    public ResponseEntity<String> getUpload(@RequestParam("file") MultipartFile file, HttpServletRequest request,
                                            @RequestParam(value = "password", required = false) String password,
                                            @RequestParam(value = "singleDownload", defaultValue = "false") boolean singleDownload,
                                            @RequestParam(value = "fileDescription", required = false) String fileDescription) {
        if (file.isEmpty()) {
            log.debug("User tried to upload an empty file. IP: " + request.getRemoteAddr());
            return new ResponseEntity<>("Please select a file to upload.", HttpStatus.NOT_ACCEPTABLE);
        }

        String fileId = fileService.processUploadedFile(file, request.getRemoteAddr(), password, singleDownload, fileDescription);
        log.debug("User uploaded file " + file.getOriginalFilename() + " from IP " + request.getRemoteAddr() + " successfully.");
        return new ResponseEntity<>("File " + file.getOriginalFilename() + " uploaded successfully! ID(" + fileId + ")", HttpStatus.OK);
    }
}
